@@ -27,8 +27,9 @@ to log, configure and control the run-time of your GUI app via command line argu
 application events
 ------------------
 
-The events described in this section are fired on application startup and shutdown. Additional events get fired in
-relation to the app states (documented further down in the section :ref:`app state events`).
+The events described in this section are fired on application startup and shutdown. Additional events get fired e.g. in
+relation to the app states (documented further down in the section :ref:`app state events`) or on start or stop of an
+:ref:`app tour <app tour start and stop events>`.
 
 The following application events are fired exactly one time at startup in the following order:
 
@@ -390,7 +391,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.2.77'
+__version__ = '0.2.78'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -849,14 +850,14 @@ class MainAppBase(ConsoleApp, ABC):
                                 flow path and the action `'focus'` will give the indexed widget the input focus (these
                                 exceptions are configurable via :data:`ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION`).
         """
-        self.vpo(f"MainAppBase.change_flow({new_flow_id!r}, {event_kwargs}) id={self.flow_id!r} path={self.flow_path}")
+        msg = f" MainAppBase.change_flow({new_flow_id!r}, {event_kwargs}) id={self.flow_id!r} path={self.flow_path}"
+        self.vpo("CHECK   " + msg)
 
         action = flow_action(new_flow_id)
         if not self.call_method(flow_change_confirmation_event_name(new_flow_id), flow_key(new_flow_id), event_kwargs) \
                 and not self.on_flow_change(new_flow_id, event_kwargs) \
                 and action not in ACTIONS_CHANGING_FLOW_WITHOUT_CONFIRMATION:
-            self.vpo(f"MainAppBase.change_flow REJECTED '{new_flow_id}'/'{self.flow_id}' path={self.flow_path}"
-                     f" kwa={event_kwargs}")
+            self.vpo("REJECTED" + msg)
             return False
 
         has_flow_focus = flow_action(self.flow_id) == 'focus'
@@ -872,7 +873,7 @@ class MainAppBase(ConsoleApp, ABC):
             # dismiss gets sent sometimes twice (e.g. on heavy double-clicking on drop-down-open-buttons)
             # .. therefore prevent run-time error
             if not self.flow_path:
-                self.dpo(f"MainAppBase.change_flow: ignoring multiple dismiss on empty flow path; action='{action}'")
+                self.dpo("IGNORED reduce on empty flow path" + msg)
                 return False
             ended_flow_id = self.flow_path.pop()
             self.change_app_state('flow_path', self.flow_path)
@@ -909,8 +910,7 @@ class MainAppBase(ConsoleApp, ABC):
             self.call_method('on_flow_widget_focused')
             self._last_focus_flow_id = flow_id
 
-        self.vpo(f"MainAppBase.change_flow CHANGED '{new_flow_id}'/'{self.flow_id}'/'{self._last_focus_flow_id}'"
-                 f" path={self.flow_path} kwa={event_kwargs}")
+        self.vpo("CHANGED " + msg + f"+path={self.flow_path} args={event_kwargs} last_foc='{self._last_focus_flow_id}'")
 
         return True
 
@@ -1466,11 +1466,11 @@ class MainAppBase(ConsoleApp, ABC):
     def widget_by_flow_id(self, flow_id: str) -> Optional[Any]:
         """ determine the first (top-most) widget having the passed flow_id.
 
-        :param flow_id:         flow id value of the searched widget's `tap_flow_id` attribute.
-        :return:                widget that has a `tap_flow_id` attribute with the value of the passed flow id
-                                or None if not found.
+        :param flow_id:         flow id value of the searched widget's `tap_flow_id`/`focus_flow_id` attribute.
+        :return:                widget that has a `tap_flow_id`/`focus_flow_id` attribute with the value of the passed
+                                flow id or None if not found.
         """
-        return self.widget_by_attribute('tap_flow_id', flow_id)
+        return self.widget_by_attribute('tap_flow_id', flow_id) or self.widget_by_attribute('focus_flow_id', flow_id)
 
     def widget_by_app_state_name(self, app_state_name: str) -> Optional[Any]:
         """ determine the first (top-most) widget having the passed app state name (app_state_name).
